# Parallel Port I/O

The Parallel Port I/O (pp_io) plugin allows you to send signals out a parallel port. This allows you to, for example, send synchronization TTL pulses to an EEG amplifier during your experiment..

The following options are available:

- Value can be a number between 0 and 255

- Duration should be a positive integer value, 'keypress', or 'mouseclick', to wait respectively for a specified interval in milliseconds, until a key has been pressed, or until a mouse button has been clicked.